from typing import Any, Iterable

__version__ = "0.1.1"


class dotdict(dict):
    """Simple dotdict implementation

    Allow access to dictionary keys via getitem and getattr

    Examples
    --------

    >>> my_dict = dotdict({"name": "John Doe"})
    >>> my_dict.name

    """

    __getattr__ = dict.get
    __delattr__ = dict.__delitem__

    def __init__(self, seq: dict = None):
        """Create a dotdict"""
        if seq is not None:
            for name, value in seq.items():
                self.__setattr__(name, value)

    def __setattr__(self, name: str, value: Any) -> None:
        """Convert dict to dotdict via dict.key"""
        if isinstance(value, dict):
            self[name] = dotdict(value)
        else:
            self[name] = value

    def __setitem__(self, key, value: Any) -> None:
        """Convert dict to dotdict via dict[key]"""
        if isinstance(value, dict):
            super().__setitem__(key, dotdict(value))
        else:
            super().__setitem__(key, value)

    def __dir__(self) -> Iterable[str]:
        """Only allow str values and ignore other dict keys"""
        return [x for x in self.keys() if isinstance(x, str)]



import pathlib

import setuptools

long_description = pathlib.Path("README.md").read_text()

setuptools.setup(
    name="dot4dict",
    version="0.1.1",
    author="zincwarecode",
    author_email="zincwarecode@gmail.com",
    description="A Python Package to enable dot-notation on dictionaries",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/zincware/dot4dict",
    download_url="https://github.com/zincware/dot4dict/archive/beta.tar.gz",
    keywords=["dotdict", "dict2dot"],
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)
